// Copyright 2017 Patrick Brosi
// info@patrickbrosi.de

#ifndef XML_NAMEDENTS_H_
#define XML_NAMEDENTS_H_

#include <map>
#include <string>

namespace xml {

// see
// http://en.wikipedia.org/wiki/List_of_XML_and_HTML_character_entity_references
std::map<std::string, const char*> ENTITIES = {
  {"aacute", "á"},
  {"Aacute", "Á"},
  {"acirc", "â"},
  {"Acirc", "Â"},
  {"acute", "´"},
  {"aelig", "æ"},
  {"AElig", "Æ"},
  {"agrave", "à"},
  {"Agrave", "À"},
  {"alefsym", "ℵ"},
  {"alpha", "α"},
  {"Alpha", "Α"},
  {"amp", "&"},
  {"and", "∧"},
  {"ang", "∠"},
  {"apos", "'"},
  {"aring", "å"},
  {"Aring", "Å"},
  {"asymp", "≈"},
  {"atilde", "ã"},
  {"Atilde", "Ã"},
  {"auml", "ä"},
  {"Auml", "Ä"},
  {"bdquo", "„"},
  {"beta", "β"},
  {"Beta", "Β"},
  {"brvbar", "¦"},
  {"bull", "•"},
  {"cap", "∩"},
  {"ccedil", "ç"},
  {"Ccedil", "Ç"},
  {"cedil", "¸"},
  {"cent", "¢"},
  {"chi", "χ"},
  {"Chi", "Χ"},
  {"circ", "ˆ"},
  {"clubs", "♣"},
  {"cong", "≅"},
  {"copy", "©"},
  {"crarr", "↵"},
  {"cup", "∪"},
  {"curren", "¤"},
  {"dagger", "†"},
  {"Dagger", "‡"},
  {"darr", "↓"},
  {"dArr", "⇓"},
  {"deg", "°"},
  {"delta", "δ"},
  {"Delta", "Δ"},
  {"diams", "♦"},
  {"divide", "÷"},
  {"eacute", "é"},
  {"Eacute", "É"},
  {"ecirc", "ê"},
  {"Ecirc", "Ê"},
  {"egrave", "è"},
  {"Egrave", "È"},
  {"empty", "∅"},
  {"emsp", "\xE2\x80\x83"},
  {"ensp", "\xE2\x80\x82"},
  {"epsilon", "ε"},
  {"Epsilon", "Ε"},
  {"equiv", "≡"},
  {"eta", "η"},
  {"Eta", "Η"},
  {"eth", "ð"},
  {"ETH", "Ð"},
  {"euml", "ë"},
  {"Euml", "Ë"},
  {"euro", "€"},
  {"exist", "∃"},
  {"fnof", "ƒ"},
  {"forall", "∀"},
  {"frac12", "½"},
  {"frac14", "¼"},
  {"frac34", "¾"},
  {"frasl", "⁄"},
  {"gamma", "γ"},
  {"Gamma", "Γ"},
  {"ge", "≥"},
  {"gt", ">"},
  {"harr", "↔"},
  {"hArr", "⇔"},
  {"hearts", "♥"},
  {"hellip", "…"},
  {"iacute", "í"},
  {"Iacute", "Í"},
  {"icirc", "î"},
  {"Icirc", "Î"},
  {"iexcl", "¡"},
  {"igrave", "ì"},
  {"Igrave", "Ì"},
  {"image", "ℑ"},
  {"infin", "∞"},
  {"int", "∫"},
  {"iota", "ι"},
  {"Iota", "Ι"},
  {"iquest", "¿"},
  {"isin", "∈"},
  {"iuml", "ï"},
  {"Iuml", "Ï"},
  {"kappa", "κ"},
  {"Kappa", "Κ"},
  {"lambda", "λ"},
  {"Lambda", "Λ"},
  {"lang", "〈"},
  {"laquo", "«"},
  {"larr", "←"},
  {"lArr", "⇐"},
  {"lceil", "⌈"},
  {"ldquo", "“"},
  {"le", "≤"},
  {"lfloor", "⌊"},
  {"lowast", "∗"},
  {"loz", "◊"},
  {"lrm", "\xE2\x80\x8E"},
  {"lsaquo", "‹"},
  {"lsquo", "‘"},
  {"lt", "<"},
  {"macr", "¯"},
  {"mdash", "—"},
  {"micro", "µ"},
  {"middot", "·"},
  {"minus", "−"},
  {"mu", "μ"},
  {"Mu", "Μ"},
  {"nabla", "∇"},
  {"nbsp", "\xC2\xA0"},
  {"ndash", "–"},
  {"ne", "≠"},
  {"ni", "∋"},
  {"not", "¬"},
  {"notin", "∉"},
  {"nsub", "⊄"},
  {"ntilde", "ñ"},
  {"Ntilde", "Ñ"},
  {"nu", "ν"},
  {"Nu", "Ν"},
  {"oacute", "ó"},
  {"Oacute", "Ó"},
  {"ocirc", "ô"},
  {"Ocirc", "Ô"},
  {"oelig", "œ"},
  {"OElig", "Œ"},
  {"ograve", "ò"},
  {"Ograve", "Ò"},
  {"oline", "‾"},
  {"omega", "ω"},
  {"Omega", "Ω"},
  {"omicron", "ο"},
  {"Omicron", "Ο"},
  {"oplus", "⊕"},
  {"or", "∨"},
  {"ordf", "ª"},
  {"ordm", "º"},
  {"oslash", "ø"},
  {"Oslash", "Ø"},
  {"otilde", "õ"},
  {"Otilde", "Õ"},
  {"otimes", "⊗"},
  {"ouml", "ö"},
  {"Ouml", "Ö"},
  {"para", "¶"},
  {"part", "∂"},
  {"permil", "‰"},
  {"perp", "⊥"},
  {"phi", "φ"},
  {"Phi", "Φ"},
  {"piv", "ϖ"},
  {"pi", "π"},
  {"Pi", "Π"},
  {"plusmn", "±"},
  {"pound", "£"},
  {"prime", "′"},
  {"Prime", "″"},
  {"prod", "∏"},
  {"prop", "∝"},
  {"psi", "ψ"},
  {"Psi", "Ψ"},
  {"quot", "\""},
  {"radic", "√"},
  {"rang", "〉"},
  {"raquo", "»"},
  {"rarr", "→"},
  {"rArr", "⇒"},
  {"rceil", "⌉"},
  {"rdquo", "”"},
  {"real", "ℜ"},
  {"reg", "®"},
  {"rfloor", "⌋"},
  {"rho", "ρ"},
  {"Rho", "Ρ"},
  {"rlm", "\xE2\x80\x8F"},
  {"rsaquo", "›"},
  {"rsquo", "’"},
  {"sbquo", "‚"},
  {"scaron", "š"},
  {"Scaron", "Š"},
  {"sdot", "⋅"},
  {"sect", "§"},
  {"shy", "\xC2\xAD"},
  {"sigmaf", "ς"},
  {"sigma", "σ"},
  {"Sigma", "Σ"},
  {"sim", "∼"},
  {"spades", "♠"},
  {"sub", "⊂"},
  {"sube", "⊆"},
  {"sum", "∑"},
  {"sup", "⊃"},
  {"sup1", "¹"},
  {"sup2", "²"},
  {"sup3", "³"},
  {"supe", "⊇"},
  {"szlig", "ß"},
  {"tau", "τ"},
  {"Tau", "Τ"},
  {"there4", "∴"},
  {"thetasym", "ϑ"},
  {"theta", "θ"},
  {"Theta", "Θ"},
  {"thinsp", "\xE2\x80\x89"},
  {"thorn", "þ"},
  {"THORN", "Þ"},
  {"tilde", "˜"},
  {"times", "×"},
  {"trade", "™"},
  {"uacute", "ú"},
  {"Uacute", "Ú"},
  {"uarr", "↑"},
  {"uArr", "⇑"},
  {"ucirc", "û"},
  {"Ucirc", "Û"},
  {"ugrave", "ù"},
  {"Ugrave", "Ù"},
  {"uml", "¨"},
  {"upsih", "ϒ"},
  {"upsilon", "υ"},
  {"Upsilon", "Υ"},
  {"uuml", "ü"},
  {"Uuml", "Ü"},
  {"weierp", "℘"},
  {"xi", "ξ"},
  {"Xi", "Ξ"},
  {"yacute", "ý"},
  {"Yacute", "Ý"},
  {"yen", "¥"},
  {"yuml", "ÿ"},
  {"Yuml", "Ÿ"},
  {"zeta", "ζ"},
  {"Zeta", "Ζ"},
  {"zwj", "\xE2\x80\x8D"},
  {"zwnj", "\xE2\x80\x8C"}
};
}

#endif  // XML_NAMEDENTS_H_

